@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: files9x.c 778 2004-08-23 10:10:32Z roms $ */
+/* $Id: files9x.c 823 2004-12-09 18:52:24Z roms $ */
 
 /*  libtifiles - Ti File Format library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -344,7 +344,6 @@ TIEXPORT int TICALL ti9x_read_backup_file(const char *filename,
   return 0;
 }
 
-// tib support not tested yet
 TIEXPORT int TICALL ti9x_read_flash_file(const char *filename,
 					 Ti9xFlash * head)
 {
@@ -384,11 +383,14 @@ TIEXPORT int TICALL ti9x_read_flash_file(const char *filename,
     }
     fread(content->data_part, content->data_length, 1, f);
 
-    switch(content->data_part[0x05] >> 4)
+    switch(content->data_part[8])
     {
-    case 2:	content->device_type = DEVICE_TYPE_89; break;	// TI89 or V200
-    case 4: content->device_type = DEVICE_TYPE_92P; break;	// TI92+
-    case 8: content->device_type = DEVICE_TYPE_89; break;   // TI89 Titanium
+	case 1: content->device_type = DEVICE_TYPE_92P; break;	// TI92+
+	case 3: content->device_type = DEVICE_TYPE_89; break;	// TI89
+	// value added by the TI community according to HWID parameter
+	// doesn't have any 'legal existence'
+	case 8: content->device_type = DEVICE_TYPE_92P; break;	// V200PLT
+	case 9: content->device_type = DEVICE_TYPE_89; break;	// Titanium
     }
 
     content->next = NULL;
