@@ -1,5 +1,5 @@
 /* Hey EMACS -*- linux-c -*- */
-/* $Id: tifiles.h 368 2004-03-22 18:42:08Z roms $ */
+/* $Id: tifiles.h 824 2004-12-27 21:44:11Z roms $ */
 
 /*  libtifiles - Ti File Format library, a part of the TiLP project
  *  Copyright (C) 1999-2004  Romain Lievin
@@ -22,9 +22,17 @@
 #ifndef __TIFILES__
 #define __TIFILES__
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 #include "file_def.h"
 #include "file_int.h"
 #include "file_err.h"
 #include "file_ver.h"
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
